@@ -14,16 +14,21 @@ use OpenAI::API::Request::Edit;
 use OpenAI::API::Request::Embedding;
 use OpenAI::API::Request::Moderation;
 
-our $VERSION = 0.21;
+our $VERSION = 0.22;
+
+my $DEFAULT_API_BASE = 'https://api.openai.com/v1';
+my $DEFAULT_TIMEOUT  = 60;
+my $DEFAULT_RETRIES  = 3;
+my $DEFAULT_SLEEP    = 1;
 
 sub new {
     my ( $class, %params ) = @_;
     my $self = {
-        api_key  => $params{api_key} // $ENV{OPENAI_API_KEY},
-        endpoint => $params{endpoint} || 'https://api.openai.com/v1',
-        timeout  => $params{timeout} // 60,
-        retry    => $params{retry}   // 3,
-        sleep    => $params{sleep}   // 1,
+        api_key  => $params{api_key}  // $ENV{OPENAI_API_KEY},
+        api_base => $params{api_base} // $ENV{OPENAI_API_BASE} // $DEFAULT_API_BASE,
+        timeout  => $params{timeout}  // $DEFAULT_TIMEOUT,
+        retry    => $params{retry}    // $DEFAULT_RETRIES,
+        sleep    => $params{sleep}    // $DEFAULT_SLEEP,
     };
 
     $self->{ua} = LWP::UserAgent->new( timeout => $params{timeout} );
@@ -35,43 +40,46 @@ sub new {
 sub chat {
     my ( $self, %params ) = @_;
     my $request = OpenAI::API::Request::Chat->new( \%params );
-    return $self->_post( 'chat/completions', { %{$request} } );
+    return $self->_post( $request );
 }
 
 sub completions {
     my ( $self, %params ) = @_;
     my $request = OpenAI::API::Request::Completion->new( \%params );
-    return $self->_post( 'completions', { %{$request} } );
+    return $self->_post( $request );
 }
 
 sub edits {
     my ( $self, %params ) = @_;
     my $request = OpenAI::API::Request::Edit->new( \%params );
-    return $self->_post( 'edits', { %{$request} } );
+    return $self->_post( $request );
 }
 
 sub embeddings {
     my ( $self, %params ) = @_;
     my $request = OpenAI::API::Request::Embedding->new( \%params );
-    return $self->_post( 'edits', { %{$request} } );
+    return $self->_post( $request );
 }
 
 sub moderations {
     my ( $self, %params ) = @_;
     my $request = OpenAI::API::Request::Moderation->new( \%params );
-    return $self->_post( 'moderations', { %{$request} } );
+    return $self->_post( $request );
 }
 
 sub _post {
-    my ( $self, $method, $params ) = @_;
+    my ( $self, $request ) = @_;
+
+    my $method = $request->endpoint();
+    my %params = %{$request};
 
     my $req = HTTP::Request->new(
-        POST => "$self->{endpoint}/$method",
+        POST => "$self->{api_base}/$method",
         [
             'Content-Type'  => 'application/json',
             'Authorization' => "Bearer $self->{api_key}",
         ],
-        encode_json($params),
+        encode_json(\%params),
     );
 
     for my $attempt ( 1 .. $self->{retry} ) {
@@ -185,9 +193,9 @@ environment variable instead.
 
 See: L<Best Practices for API Key Safety|https://help.openai.com/en/articles/5112595-best-practices-for-api-key-safety>.
 
-=item * endpoint [optional]
+=item * api_base [optional]
 
-The endpoint URL for the OpenAI API. Default: 'https://api.openai.com/v1/'.
+The api_base URL for the OpenAI API. Default: 'https://api.openai.com/v1/'.
 
 =item * timeout [optional]
 
